@@ -7,7 +7,7 @@ register = template.Library()
 
 
 @register.simple_tag
-def svg_inline(svg_target, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_DEFAULT_SIZE):
+def svg_inline(svg_target, theme=None, size=None):
     if isinstance(svg_target, Svg):
         return svg_target.render_html(theme, size)
     else:
@@ -17,7 +17,7 @@ def svg_inline(svg_target, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_D
 
 
 @register.simple_tag
-def svg_django(svg_target, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_DEFAULT_SIZE):
+def svg_django(svg_target, theme=None, size=None):
     if isinstance(svg_target, Svg):
         return svg_target.render_django(theme, size)
     else:
@@ -27,7 +27,17 @@ def svg_django(svg_target, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_D
 
 
 @register.simple_tag
-def collection_styles(collection, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_DEFAULT_SIZE):
+def svg_preview(svg_target, theme=None, size=None):
+    if isinstance(svg_target, Svg):
+        return svg_target.render_preview(theme, size)
+    else:
+        svg = Svg()
+        svg_composed = svg.key_decomposer(svg_target)
+        return svg_composed.render_preview(theme, size)
+
+
+@register.simple_tag
+def collection_styles(collection, theme=None, size=None):
     return collection.render_styles(theme, size)
 
 # class SvgLayoutNode(template.Node):
